IcaoCccdProtocol class final

Implemented types

Constructors

IcaoCccdProtocol({CccdPassportFactory? passportFactory, bool includePortrait = true, bool includeDg13 = true})

Properties

hashCode int
The hash code for this object.
no setterinherited
includeDg13 bool
final
includePortrait bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

authenticate({required ComProvider transport, required CccdCredential credential}) Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readData({required ComProvider transport, CccdReadProgress? onProgress}) Future<CccdData>
override
reset() Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited