NfcProvider class

Inheritance

Constructors

NfcProvider()
Android Default timeout.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration
getter/setter pair

Methods

connect({Duration? timeout, String iosAlertMessage = "Hold your iPhone near the biometric Passport"}) Future<void>
/ Can throw ComProviderError.
override
disconnect({String? iosAlertMessage, String? iosErrorMessage}) Future<void>
/ Can throw ComProviderError.
override
isConnected() bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIosAlertMessage(String message) Future<void>
On iOS, sets NFC reader session alert message.
toString() String
A string representation of this object.
inherited
transceive(Uint8List data, {Duration? timeout}) Future<Uint8List>
Can throw ComProviderError.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

nfcStatus Future<NfcStatus>
no setter