MrtdSM class

Class defines secure messaging protocol as specified in ICAO 9303 p11.

Inheritance

Constructors

MrtdSM(SMCipher smCipher, SSC _ssc)

Properties

cipher SMCipher
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ssc SSC
no getter

Methods

blockLen() int
decryptDataDO(DecodedTV? dtv) Uint8List?
generateDataDO(CommandAPDU cmd) Uint8List
generateK({required Uint8List data}) Uint8List
generateM({required CommandAPDU cmd, required Uint8List dataDO, required Uint8List do97}) Uint8List
generateN({required Uint8List M}) Uint8List
maskCmd(CommandAPDU cmd) CommandAPDU
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseDataDOFromRAPDU(ResponseAPDU rapdu) DecodedTV?
Returns decoded data from DO85 or DO87 if they are present in rapdu.
parseDO8EFromRAPDU(ResponseAPDU rapdu, int offset) DecodedTV
parseDO99FromRAPDU(ResponseAPDU rapdu, int offset) DecodedTV
protect(CommandAPDU cmd) CommandAPDU
override
toString() String
A string representation of this object.
inherited
unprotect(ResponseAPDU rapdu) ResponseAPDU
override

Operators

operator ==(Object other) bool
The equality operator.
inherited