Pair<T1, T2> constructor
const
Pair<T1, T2> (
- T1 first,
- T2 second
Creates a new Pair with items first and second.
Implementation
const Pair(this.first, this.second);
Creates a new Pair with items first and second.
const Pair(this.first, this.second);