CccdVerificationResult class final
Constructors
- CccdVerificationResult({CccdData? nfcData, CccdOcrResult? ocr, CccdFaceMatchResult? faceMatch, CccdLivenessStatus livenessStatus = CccdLivenessStatus.notEvaluated})
-
const
Properties
- documentNumberMatches → bool
-
no setter
- faceMatch → CccdFaceMatchResult?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isConsistent → bool
-
no setter
- livenessStatus → CccdLivenessStatus
-
final
- nfcData → CccdData?
-
final
- ocr → CccdOcrResult?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → CccdVerificationStatus
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited